@@ -1,8 +1,7 @@
 from typing import Type, Dict
 
 import nonebot
-from nonebot import get_driver, logger
-from nonebot.adapters.onebot.v11 import Bot
+from nonebot import get_driver, logger, Bot
 from nonebot.exception import IgnoredException
 from nonebot.internal.adapter import Event
 from nonebot.internal.matcher import Matcher
@@ -26,7 +25,7 @@ async def check(matcher: Matcher, bot: Bot, event: Event):
     if service is None:
         return
 
-    allow = await service(bot, event)
+    allow = await service.check(bot, event)
 
     if not allow:
         raise IgnoredException("permission denied by nonebot_plugin_access_control")
